
# q-expansion of newform 7595.2.a.w, downloaded from the LMFDB on 13 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 7595
weight = 2
poly_data = [2, -14, 4, 90, -2, -130, 0, 67, 0, -14, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[88, -222, -890, 282, 1374, -134, -724, 28, 153, -2, -11], 2], [[-94, 222, 892, -282, -1374, 134, 724, -28, -153, 2, 11], 2], [[-112, 280, 1068, -380, -1634, 190, 858, -41, -181, 3, 13], 2], [[112, -290, -1068, 382, 1634, -190, -858, 41, 181, -3, -13], 2], [[-142, 362, 1378, -458, -2134, 212, 1124, -43, -237, 3, 17], 2], [[-156, 436, 1424, -630, -2154, 322, 1126, -69, -237, 5, 17], 2], [[-81, 217, 802, -280, -1244, 134, 657, -28, -139, 2, 10], 1], [[174, -440, -1720, 562, 2652, -268, -1392, 56, 293, -4, -21], 2], [[166, -426, -1573, 557, 2403, -268, -1259, 56, 265, -4, -19], 1]]

hecke_ring_character_values = None
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, -1, -1, 0, 0, 0, 0, 0, 1, -1], [-1, 0, 0, 0, 1, -1, 1, 0, 0, 0, 1], [-2, 1, -1, -1, 0, 0, 1, 0, 0, 0, 0], [2, 1, 1, -1, 0, 0, -1, -1, 0, 0, 0], [0, 0, 0, 1, 0, 1, -1, 1, 0, -1, 0], [-1, 1, 0, 0, 0, 0, 0, 0, -2, 0, -1], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-2, -1, -1, 1, -1, 1, 0, 1, -1, -1, 0], [1, -2, 2, 1, -1, 0, -2, -1, 1, 1, 0], [-4, 1, -1, 0, 0, 0, 0, 1, 0, 1, 1], [0, -1, 1, 0, 1, -1, 0, 2, 0, -1, 0], [-1, 1, -2, 0, 0, 1, 1, 2, -1, -1, -1], [0, -1, 0, -1, -1, -1, 0, -2, 0, 1, -1], [1, 2, 0, -2, 2, 3, 0, 2, -1, -1, -1], [1, 1, 0, -1, 0, -1, 1, 0, 0, -1, -1], [1, 5, 4, -1, 0, 1, 1, -2, 2, -1, 2], [0, 0, 0, 1, -4, 2, -1, 0, 0, -1, 0], [-2, -2, -1, -1, -1, -2, 1, -3, -1, 1, -1], [1, -2, -1, 2, -2, 0, -1, 0, -1, 0, 2], [0, 0, 1, -2, -1, -1, 0, 1, 1, -2, 0], [0, -2, -1, 4, -2, 0, -3, 1, -1, -1, -1], [0, -2, -4, 1, -1, 4, -3, 2, -1, 1, -4], [0, -1, 2, -2, 1, 1, 1, -1, 2, 2, -1], [-3, -2, -1, -1, 1, -1, 3, 1, 1, 0, 0], [-5, 1, -1, -3, 2, -2, 0, 2, 1, 0, 0], [-2, 2, 2, 0, 1, -2, 0, -1, 2, 0, 2], [-2, 6, 3, 0, 4, -2, 3, -2, 1, -1, 3], [-1, 2, 0, -3, 3, 0, 2, -1, 1, 1, 4], [-2, 3, 0, -2, 1, -2, 0, -6, 4, 3, 3], [3, 2, 3, 2, -2, 2, 0, 0, 2, -1, 3], [-4, -4, -1, 1, 0, 1, 0, 5, -1, -2, 0], [0, 0, -4, -2, -4, 4, -3, 3, -3, -3, -4], [3, -6, -2, -1, -4, -2, -2, 0, 1, -1, -2], [-1, -2, 1, 3, 0, 1, -3, 2, -3, 0, -2], [-5, 1, -2, -4, 2, 2, 1, 0, 1, 3, -4], [-3, 3, 2, -5, 5, 1, -1, -1, 3, -1, 3], [1, 2, -2, 2, -1, 4, 0, 2, -3, -1, 1], [-1, -1, 2, -3, 2, -1, 2, -1, 2, 2, -1], [5, -1, 3, 2, -2, 1, -3, -4, 4, -1, 2], [-6, 0, -2, -2, -2, -5, 0, -5, 2, 4, 4], [-5, -4, -2, 2, -6, -3, 0, -1, -2, 1, -1], [-6, -3, -3, 2, -4, -1, 2, 3, -3, 1, -1], [-4, 2, 3, -5, 2, -2, 0, 0, 0, 0, 2], [2, -4, -3, -1, -1, 1, 3, 2, 1, -1, 1], [-4, 2, -4, -3, -3, 1, -1, -3, -2, -1, 3], [0, 2, 0, -7, 1, -2, 0, -1, 3, 2, -3], [2, -2, 6, 6, 0, -1, -2, -1, 4, 2, 2], [-4, -1, 2, 6, -3, -4, -2, -2, 1, -1, 0], [-3, -5, -4, 5, -5, -1, 0, 2, -2, 2, -1], [-4, 3, -3, -2, 1, 7, 0, 4, -3, -1, -5], [-1, -1, -2, 1, -7, 1, -1, 3, -6, -1, -5], [4, -1, 5, 4, 4, -2, 2, 3, -2, -3, 3], [3, -2, -1, 3, 1, 0, 0, -3, -1, 3, 2], [-1, 2, -7, -6, -1, 2, 0, -3, 2, 3, 1], [-6, -1, -2, 4, 1, 0, 0, 6, -2, -1, 1], [-2, 0, 3, 1, 1, -2, -2, 1, 2, 2, 1], [-6, -4, -3, -1, -1, -7, 2, -2, 0, 2, -2], [1, 2, -2, -3, 2, 4, 2, 0, -2, -1, -2], [-5, -1, -5, -3, -3, -1, -2, 2, -3, -2, -4], [9, -2, 5, -2, 1, -5, 0, -4, 2, -3, 1], [-4, -5, -3, 0, -2, 7, -6, 4, -1, -1, -6], [2, 1, -3, 0, -1, 2, -2, -5, -1, 1, -1], [-6, -6, 4, 5, -5, -2, 0, -2, 4, 4, 5], [-7, 0, -5, -2, -4, 5, -1, 3, -1, -2, -4], [2, -5, 1, 6, -2, -4, 2, -3, -6, -1, -1], [5, 4, 2, 4, 0, -2, 1, 3, -4, -2, 2], [-8, 5, 4, 5, 3, -4, 2, -2, 0, 1, 3], [2, 2, 2, -1, 0, 1, 1, -2, -3, 1, 4], [-9, 1, -4, -3, 6, -2, 2, 4, 1, -2, 4], [-10, 5, 3, 0, 9, -5, 8, 0, -1, -1, 3], [-3, 3, 2, 1, 4, 3, 1, -6, 6, 3, 4], [-2, 1, 7, 0, 2, 1, -1, -4, 9, -4, 6], [-7, -2, -3, 1, -2, 2, 5, 1, 0, -2, 0], [6, 0, 4, -1, -3, -5, 1, -9, 2, 1, 5], [4, -1, 0, 7, 0, 4, -2, 2, 3, -3, 5], [3, 5, 0, 3, 1, 3, 4, -4, 2, 2, -1], [-1, 4, -3, -8, -1, -9, 6, -6, 2, 5, 5], [-6, 4, -2, -1, 2, 6, -5, 3, -4, 1, -6], [1, -3, 4, 2, 3, -7, 0, 0, -2, 0, 7], [0, -2, 2, 1, 0, 4, -5, -2, 6, 5, 0], [-8, 4, -8, -1, -1, -6, 3, 0, -3, 3, 2], [5, 6, 3, -1, 11, 0, 1, 0, -1, 0, -2], [3, 6, 6, 3, 4, 2, 4, 4, 2, -3, -1], [-1, -6, 5, 5, -4, 0, 2, 0, -1, 1, -2], [-6, 5, 1, 1, 7, -3, 4, 0, -4, -1, 6], [-3, 1, 6, 0, 7, 3, -2, 1, 0, -4, -4], [8, -1, 4, 10, 1, 1, 1, 1, 0, 0, -1], [-6, 1, -1, 0, 1, 6, 2, 5, 3, -1, -2], [-1, -5, -3, 3, -1, 4, 0, 2, 5, -2, 3], [-11, 5, -3, -3, 3, -4, 3, 1, 0, -3, 1], [-4, 7, -1, -6, 3, 6, 1, -3, 3, 4, -5], [5, -5, 0, 1, 3, 1, -1, 9, -3, -5, -1], [-2, 9, 0, 0, 5, -2, 2, 4, -6, -1, -1], [8, -2, 4, 3, 7, -4, 1, 4, 1, -7, 4], [-4, -7, -2, 9, -5, 0, -3, 2, -2, -4, 1], [-5, 5, 3, 4, 9, -1, 5, -5, 0, 1, 3], [-4, 0, -2, 4, 1, 2, -4, -5, 2, 2, 0], [-3, -7, -4, 3, -4, 0, 2, -5, -3, 2, -3], [-1, 0, 0, 3, -6, 0, -6, -4, 3, 7, -2], [8, -1, 2, 1, -4, 2, -2, 2, 4, -1, -2], [-5, -2, -1, -6, -1, 6, -1, 1, 7, 2, -2], [3, -2, -1, 4, -1, 1, -4, -8, 7, 3, 0], [-2, 11, 3, -8, 4, 7, -3, -4, 1, 0, -2], [-4, -11, 5, 5, -2, 4, -1, -1, -1, 0, 1], [-8, -8, -4, -3, 1, -4, 1, -4, 2, 5, 5], [-6, 2, 5, 0, 6, 5, -2, 0, -1, 4, -2], [10, 6, 7, 1, 9, 5, -2, -2, 4, -6, 6], [-10, -2, 0, -3, 5, -1, 2, -2, 5, 4, -5], [-6, 2, 2, -2, 3, -3, 2, -4, 6, 6, 6], [-8, -3, -1, 8, 4, -1, 6, -3, -3, 3, 1], [-3, -3, -3, -6, -2, 2, 0, -4, 2, 0, 5], [8, -4, 13, 0, 6, 4, -7, 1, 6, -3, 3], [11, -5, -1, -4, -1, -2, 0, 2, -3, -2, -7], [-3, 6, 0, -1, 9, -3, 5, -4, 2, 2, 3], [-12, -3, -3, 4, -10, -1, 0, -3, -3, -3, 3], [-10, 6, 2, -1, 3, -2, -1, 0, 0, 3, 7], [5, 0, 11, 9, 4, 1, -1, 0, 5, -2, 3], [-14, 3, -6, -7, 1, 1, 9, -3, 2, 4, 5], [-5, -8, -5, 4, 2, 1, 2, 6, -6, 3, 2], [-10, -11, -11, 2, -1, 4, 0, 3, -5, 1, -3], [-4, 3, -3, -7, 4, -6, 5, 5, -2, 2, -4], [0, 4, -2, -6, 3, 5, 2, 0, -3, 2, -7], [-1, 1, 3, -6, 2, 2, 1, -1, 2, 3, -4], [5, 5, -2, 6, -8, 1, -2, 3, -3, -6, -2], [-8, 6, 1, -4, 4, -2, 1, -1, 0, 1, 11], [-13, -6, 0, -1, 8, 0, 0, 0, -2, 7, 0], [-6, -9, -5, -8, -1, -2, -1, -5, 1, 4, 1], [7, -9, 1, 3, -7, -4, -6, -2, -1, 0, 3], [2, -6, 5, 2, 10, -3, 3, 2, 1, 3, -2], [-15, -5, -10, 0, -2, -1, 3, -4, -1, 1, 1], [14, -3, 9, -1, -1, -7, 0, -8, 6, 7, 2], [1, 2, -6, 8, -6, 6, -1, 7, -10, 2, -8], [-2, -1, -1, 12, -6, -3, 4, -2, -3, -1, -2], [-3, 5, -1, 2, -1, 10, 0, 8, -5, -10, -3], [-7, -6, 5, 4, -2, -3, -4, -4, 6, 1, 2], [-13, 3, 7, -12, 12, -2, 3, -1, 4, 3, 6], [15, -8, 9, 3, -4, 5, -11, -4, -1, 0, -3], [3, 12, 2, -1, 2, 4, -2, 0, 0, -3, 1], [-3, -5, 3, -1, -3, 2, -2, -2, 3, -6, 3], [-2, 2, -2, 7, -8, 1, 3, -3, -2, -1, -4], [0, -4, 5, -2, 5, -9, -2, -7, -1, 4, 6], [8, 12, 11, 5, 2, -3, 2, 3, 3, -2, 3], [6, 1, 0, -2, 1, -3, 1, 5, -5, 2, -9], [-4, 4, -7, 9, 1, -3, 8, 2, -5, 0, 2], [9, 1, -6, 4, -10, 9, -6, 7, -5, -2, -12], [7, 4, -3, 5, -1, -6, 3, 3, -2, -6, 5], [-6, -1, 5, -4, -5, -1, -2, -6, 3, 1, 3], [0, 0, 15, 12, 3, -3, 4, -5, -1, -6, 4], [2, -5, 3, -6, -2, -6, 0, -3, 2, -3, 9], [7, 1, 0, -6, 6, 0, 2, -10, 5, 6, 4], [-10, -8, -4, 8, -3, 1, 2, -2, -2, 0, -2], [-8, 12, 13, 2, 18, -2, 4, 4, 0, 0, 2], [0, 2, -1, 6, -2, -5, 3, 4, -7, -7, 0], [1, 7, -6, -5, 2, 7, -2, 1, 2, 4, -11], [4, 5, 4, -2, 5, -3, -1, -9, 0, -2, 1], [13, 8, -2, -10, 9, -1, 4, -5, 3, 1, 5], [1, 3, -1, -9, 7, -10, 10, 0, 3, -6, 9], [11, 6, 6, 0, 0, -3, 0, -11, 4, 7, 3], [1, -14, -6, -6, -5, -1, -1, -4, 11, 2, 4], [14, -11, -7, 5, -10, 0, 1, 3, -2, -2, 0], [-4, 8, 6, -12, 12, 2, 0, -4, 6, -4, 4], [1, 3, 3, 0, -5, 2, 0, 6, -5, -4, -11], [-9, 0, -1, 3, 4, 2, 4, 8, -3, -5, -2], [11, 11, -3, -5, 3, 1, 6, -2, 3, 6, -8], [14, -5, 6, 15, -6, 0, -12, -2, -1, -7, 3], [-8, -12, 5, 0, -7, -1, -5, -10, 7, 7, 3], [7, -7, 5, -6, -4, 6, -8, -6, 5, 0, -4], [3, -13, 0, -3, 5, -1, 2, 0, 8, -2, 5], [16, -6, -9, 1, -16, 6, -8, 4, -4, -6, -4], [-12, 9, 3, 2, 4, 5, 0, -3, 3, -7, -1], [-2, 2, -2, 1, 7, 4, 7, 8, -5, -11, 0], [4, -3, 0, 10, -10, -4, 2, 1, -12, 1, -7], [7, 7, 0, -8, 9, 1, 2, 8, -8, -8, -3], [5, -5, 2, -1, -2, 10, -1, -1, 9, -1, -2], [12, -2, -8, 2, 2, 10, 0, 4, -4, -2, -6], [1, 2, 7, -3, -4, -10, 4, -6, 1, 1, 12], [-8, -18, -6, 8, -1, -5, 0, -2, 0, 2, -2], [-7, 1, 6, -12, 9, 3, -2, -4, 1, 6, -6], [0, -3, 3, -2, 2, 2, -4, 10, -5, -7, -9], [-5, -11, -7, 2, -11, -5, -9, 8, -2, 3, -3], [3, -3, 8, 1, 5, 3, -1, -3, 8, -1, -5], [9, 4, 8, 0, 5, 1, -2, 5, 5, -1, -5], [-12, -5, 7, -2, 1, -4, -2, -9, 5, 5, 3], [-5, 1, 2, -5, 5, -3, 3, 7, 7, -1, 7], [-2, -6, 3, 2, 6, 2, -3, -5, 9, 7, 4], [3, -16, -14, -7, -9, 2, -2, -1, -3, 5, -10], [-6, 4, -1, -14, 3, -7, 3, -6, 5, 5, 1], [-8, 8, 0, 0, 9, 0, 6, 7, -8, -2, -4], [1, 4, 10, -2, 9, 8, -10, 8, 8, -3, 2], [7, -9, -1, 8, 2, 0, -2, 13, -10, -12, -4], [-12, -7, -9, 0, 3, -3, 0, 4, -5, 9, -5], [-14, 11, 3, -4, 0, -1, -4, -10, 5, 3, -2], [-1, -9, 11, 0, -6, -4, -7, -5, 4, 1, 0], [2, 8, 4, -14, 6, 12, 0, -2, 8, 2, -2], [-13, 12, 0, 1, 2, -4, 4, -2, 8, 1, 6], [-14, -10, -1, 11, -5, -3, -4, 8, -8, -6, 2], [5, -19, -3, -6, -3, 0, -3, 12, -7, -5, -11], [-11, -10, -1, -4, -2, -2, 2, -4, 4, 3, 1], [-12, -4, -7, -7, -3, 7, 0, 2, -3, 0, -4], [0, 12, -7, 8, 3, 11, 1, 7, -12, -5, -3], [-8, 9, -2, -3, 9, -5, 2, 0, 0, 1, 1], [19, 8, 3, 11, -6, -4, -5, 8, -11, -6, -6], [3, -10, -2, 1, -3, 8, 4, 15, -7, -1, -16], [14, -12, -9, 2, -12, -2, 3, -4, 7, 1, 5], [7, 13, 2, -7, 10, 3, 3, -6, -2, 9, -2], [10, -12, 6, -3, -3, -6, -7, 4, 1, -1, 8], [-4, 5, -3, -2, 11, -6, 7, 6, -7, -2, -2], [1, 0, 10, 18, 11, -3, -2, 1, 7, -5, 9], [2, -1, 1, 2, -7, 7, -8, 4, -1, 3, -11], [6, 15, 3, 10, -1, -3, 2, -6, 2, 1, 8], [-1, 13, 0, -10, 6, 3, -6, 5, 3, 0, 4], [4, 4, 0, -14, 10, -8, 6, 4, 0, -8, 14], [1, -7, -2, 11, -10, 2, -11, 7, -4, -3, -9], [3, -2, -4, -10, -2, 0, 3, -5, 6, 6, 2], [16, 6, 1, 14, 2, -2, 3, -8, 7, 5, 9], [14, 11, -1, -10, 4, 2, -6, 6, -3, -5, -7], [-7, -3, 5, 10, -4, 2, -9, -1, 5, 1, 7], [11, 8, -2, 0, -4, -4, 9, -9, 0, 6, 0], [12, -12, 0, 12, -3, -13, -2, -2, -7, -4, 1], [18, -3, 11, 24, 0, 4, 2, -2, -1, -5, 13], [-5, 1, 5, 7, -1, 3, 8, 8, -1, 0, -4], [-9, 3, -8, 4, 2, -2, 6, 4, -7, 2, 4], [-7, 7, 10, -17, 5, -3, 7, -9, 7, -1, 3], [0, -8, -8, -5, -17, -2, 0, 8, -9, -2, -12], [4, -24, -7, 5, -11, 6, -11, 2, -2, -5, -11], [30, -6, 0, -7, -10, 7, -9, 6, -1, 1, -8], [-25, 3, -14, -2, -6, -9, 5, -4, -1, 13, 1], [6, -7, -4, 0, 4, 11, -11, 12, 5, 2, -9], [-14, -10, -13, 12, -3, 6, -3, 4, -4, 3, 5], [-20, -4, -14, 4, -8, 2, 0, 0, -3, 8, -5], [21, -1, 13, 7, -7, -2, -1, -4, -3, 1, 7], [-8, -2, 6, 1, 6, 2, -6, -4, 4, 12, -4], [18, 2, 7, 2, 11, -9, 5, -13, 6, 7, -1], [-6, -7, -15, -4, -10, 3, -4, 9, -1, 9, -15], [-5, 6, -7, -5, -2, -2, 10, -6, 4, 1, 7], [-14, -5, -5, -12, 4, -5, -4, 1, 9, 5, 5], [11, -1, 6, 5, 8, -6, -1, -9, 6, 11, -5], [16, 8, 0, 12, -11, -2, -4, 3, -4, -4, 0], [-3, -23, 2, 8, -10, -11, -1, -8, -8, -1, -6], [-13, 0, -2, 7, 0, 0, 8, 8, -15, -3, 4], [-17, -12, -27, -3, -10, 8, -5, 10, -13, -6, -16], [0, 13, 9, 0, -3, -8, -2, -13, 5, 13, 0], [-1, 8, 0, 3, 3, -2, 5, -4, -7, 10, -9], [11, -8, -3, -2, 9, 6, -4, 1, -6, -3, -7], [-4, 16, 10, -22, 14, -18, 7, -7, 9, 3, 8], [1, 10, 3, -5, 8, -5, -3, -2, -5, 6, -2], [-4, -6, -2, 10, -11, -2, -2, 11, -12, -6, 6], [4, 0, -4, -12, 8, 10, 0, 6, 0, -6, -8], [8, -4, 8, -3, -6, -9, 5, -3, 2, -3, 0], [-12, -10, -7, 2, -7, 3, -3, 11, -4, -9, -11], [2, -11, 4, 8, -7, -7, -1, -3, 7, -8, 15], [7, 5, -1, 8, 2, -7, 11, -6, -4, 9, 4], [-22, 12, -3, 0, 3, -6, 5, 2, 0, 5, -1], [28, 17, 19, -4, 12, -6, 7, -8, 10, -10, 12], [0, -5, 17, 13, 2, -6, 5, 1, -1, 0, 9], [-3, 11, 1, -10, 18, -4, 17, -7, 8, 1, 9], [-5, 13, 0, 1, -2, 10, 3, 5, -8, -11, -3], [-6, -5, -2, -17, -16, -3, -8, -4, -3, 1, -6], [-10, 3, 2, -8, 6, -2, -2, -17, 0, 1, 3], [-6, -8, 3, 7, -11, -5, -6, -4, 4, 2, 0], [-19, 5, -4, -1, 0, -6, 15, 4, 1, 5, 6], [13, -8, 0, 14, -8, 2, -5, 7, -4, -6, -10], [12, -4, 15, -2, 4, 1, -9, 8, 3, -3, -2], [21, 2, 4, 3, -9, 4, 0, -1, -3, -7, -8], [31, 5, 8, 1, -9, 1, -13, -9, 8, -9, 3], [4, -1, 13, 24, 3, -8, 2, 15, -5, -13, 9], [14, 10, 5, 8, -3, 1, -7, 11, -6, -5, -5], [-6, 0, -6, -1, -4, 11, 1, 13, -8, -1, -12], [-17, 16, 6, 3, 7, -2, 6, 4, -9, -5, 3], [-14, -7, -16, 6, -3, 2, 4, 6, -8, -5, -3], [-3, 16, 10, 14, 1, 3, 3, -7, 6, -2, 15], [-8, 8, 10, 7, 17, 5, -1, 7, -6, 3, -1], [9, 2, -19, 7, -8, 3, 7, 2, -13, 4, -12], [-13, -3, -6, 12, -10, 20, 2, 18, -5, -4, -12], [-12, -14, -5, 10, -10, -14, -3, 7, -3, 5, -6], [22, -4, -4, 24, -11, 2, -4, 3, -4, 6, -2], [0, 5, 11, 0, -7, -1, 2, -4, -4, -7, 4], [6, 4, 15, 17, 4, 0, 0, 12, -2, -2, -2], [-23, 1, -1, 6, -2, -2, -1, -3, -3, -3, -1], [1, -12, -12, 6, -16, 0, -1, 1, -8, -2, -12], [-21, -10, -5, 2, 5, -5, 0, 0, 7, 5, 4], [13, 11, 1, -12, 2, -2, 4, -4, 2, 2, 3], [-6, 8, 1, 11, -7, 11, -7, 2, -12, -7, -4], [2, -4, -19, 5, -3, 5, -1, 8, -2, -1, -8], [-17, -8, -1, 10, -1, 13, -2, 2, 0, -1, -1], [10, 6, 1, -2, 7, 5, 0, -1, 13, 2, 10], [-12, -2, -6, 10, -10, -7, 2, -5, -3, -2, 4], [17, -7, 12, 5, -3, -9, -5, 1, -3, -5, 3], [5, 15, 8, 3, 8, 4, 8, -1, 3, 6, 5], [-1, -10, 6, 6, 6, -6, 1, -1, -2, 8, 6], [7, -1, 0, -10, 0, 5, -9, -12, 13, 7, -7], [-11, -5, -14, 5, -3, -3, 2, 8, -6, 0, -3], [-3, 8, -1, -8, 6, -8, 0, -6, 6, 3, -1], [5, 9, -1, -23, 15, -13, 2, -12, 3, 0, 4], [19, -2, 9, 18, 9, 0, 8, -1, 2, -1, 5], [-30, 10, -6, 8, 10, -4, 3, 16, 0, -3, 0], [-12, 21, 2, 4, -3, -3, 7, -3, -8, -2, -9], [-2, -2, 13, 18, -5, -10, -6, -1, -4, 4, -4], [7, 23, 19, -11, 9, 2, -1, -11, 4, 1, 1], [-17, 5, -2, -13, -4, 2, -1, 7, 12, 1, 3], [4, -3, -7, -5, -4, -4, 2, 8, -7, -3, 7], [12, 20, 12, -16, 19, -8, 10, -13, 14, 4, 10], [-9, -4, -9, -1, 3, 6, -5, 13, 2, 2, -5], [-2, 16, 4, -6, 16, 2, 12, -8, 10, 4, 10], [12, 1, 6, -2, -1, -8, 0, 6, -4, -7, 11], [-4, 2, 6, 14, 10, 0, 2, 6, 2, -10, 4], [-13, -2, 5, 6, -10, -3, 1, -4, 12, -4, 10], [-17, 4, -15, -5, -12, 6, -5, 11, -8, -4, -2], [0, -2, -12, -12, -17, 4, -2, -3, 4, 6, -9], [3, -3, -2, 24, -7, -7, 2, -1, -4, 6, -2], [-3, 14, -9, -9, 1, 24, -3, 16, -9, -4, -16], [-14, 21, 9, -5, 2, 5, -2, -7, 14, -7, 6], [1, 5, -8, -14, -8, 7, 0, 1, -5, -4, -4], [-6, 9, 0, -3, 12, 4, 1, 9, -5, -8, -8], [16, -15, -1, 8, -5, -1, -6, 2, 10, 1, 2], [0, 8, -5, -8, 8, -12, 3, -9, 11, 1, 0], [-15, -1, -4, 2, -1, -7, 8, 2, 7, 6, 2], [6, 8, -1, 4, -5, 0, 0, -3, -16, -8, -2], [7, 4, 16, 10, 8, -10, 11, -9, 4, 14, 10], [-7, -3, -14, -23, 3, 1, 11, 7, -10, 9, -9], [10, -1, 9, -8, 0, 11, -20, 1, 3, -5, -9], [8, 17, -15, 11, -5, -3, 0, 2, -12, -3, 8], [-12, 2, -6, 7, 5, 2, -3, 12, -8, 1, -1], [16, -10, 18, 24, 4, -8, 2, -8, 6, 10, 2], [20, 14, 15, -2, 10, -8, 13, 2, 5, -1, 13], [8, 2, 2, 2, -3, -16, 9, 1, -3, 1, 9], [-22, -28, -3, 14, -11, 8, -1, 8, 6, 3, -9], [14, -5, 3, -2, 8, -15, 10, -9, 1, 5, 9], [16, 3, 16, 4, 16, -5, 5, -18, 19, 6, 15], [-8, -2, -18, 6, 0, -2, 5, 10, -8, 1, 0], [-26, 6, -11, 2, -5, -20, 9, -16, 4, 9, 17], [-5, 5, 5, -3, -17, -17, 6, -8, -5, 6, -2], [1, -22, -1, 5, -16, -2, -11, 5, -10, 2, -6], [-6, 9, 8, 13, 16, -6, 2, 4, -4, -5, 4], [-23, 2, -11, -20, -7, 1, -8, -12, 4, -3, -1], [-7, -23, -2, 10, 4, 1, -7, 18, 0, -7, 0], [-29, -10, -1, 4, 14, -9, 3, -1, -1, 14, 6], [-13, -7, -24, 4, -10, 5, -5, 12, -19, -3, -13], [30, -15, 1, 15, -13, 1, -10, -4, -6, -7, 8], [-4, -4, -6, -12, 2, -22, 13, -13, 1, 21, 0], [-4, 22, 8, -16, 10, -4, 8, -4, 6, -8, 8], [3, -13, 13, 24, -7, -20, -3, -6, -7, -1, -1], [11, -4, -18, -3, -1, -8, -2, -3, -5, 7, 2], [-13, 9, -8, -2, 11, 25, -4, 11, -6, -4, -12], [3, -8, 1, 18, -16, -2, -6, 8, -20, 3, -11], [4, -14, -16, 24, -22, 2, -4, 10, -23, -4, -6], [-8, 31, -1, 14, 7, -9, 12, -4, -1, -1, 13], [-18, 11, 1, 3, -5, 5, 8, 7, -3, -1, -10], [4, 6, -3, 4, 0, 11, 5, 10, -1, -9, -4], [-11, 7, 7, -19, 3, -20, 9, -16, 1, 3, 5], [-29, 17, 6, -9, 4, 2, -5, -11, 7, 3, 2], [1, -13, -22, -13, -10, 10, -5, 0, 1, -5, -8], [27, 21, 8, 6, 9, -5, 14, 0, -7, -8, -2], [-8, -7, 7, 10, 1, -3, -2, -8, 3, -5, 9], [-8, 6, -9, -4, 3, -2, -8, -1, 4, 0, -6], [4, 9, 3, -4, 5, 10, -10, -1, 5, -7, 5], [0, 16, -6, -32, -8, 7, -4, 1, -4, -8, -10], [3, -2, 4, 12, 8, -5, 6, 6, 3, -5, 3], [7, 11, -6, -14, -3, 9, 2, -13, -6, 8, 2], [21, 9, 2, -15, 11, 4, -3, 2, -5, -11, -11], [5, -1, 14, 10, 6, -10, 8, -8, 3, 10, 4], [1, 1, -4, -13, 4, -2, -4, -9, -5, 12, -7], [-11, 13, 1, 12, 2, 14, -7, -3, -4, -1, -3], [-2, 9, -13, -14, -2, 8, -4, 5, -2, 7, -9], [12, -8, 7, 0, -5, -5, -9, -5, -5, 3, -1], [-12, -22, -15, 10, -8, -1, 1, 10, 1, 7, -2], [13, -26, -5, 19, -2, -7, -9, 2, 5, 0, 5], [20, 13, 13, -14, 9, -3, -16, -4, 5, 5, -1], [-36, -10, -19, -4, 8, 3, 9, 12, -3, 5, -2], [0, 19, -3, -24, -5, 10, 0, -3, 5, 5, -10], [-31, 9, -12, -15, -4, 4, -8, 1, 3, -4, -13], [9, 9, -12, -4, -13, -15, 6, 0, 5, -2, 6], [-4, -16, 11, 13, -10, -18, 4, -6, 0, 6, -2], [21, -1, 27, -8, 12, 2, -3, -15, 14, -11, 7], [14, 16, 13, 10, -3, 5, 3, 9, 8, -3, 7], [-1, 8, 16, -5, -7, -6, -4, -12, 1, 5, 3], [9, -16, -17, 7, -7, 14, -8, 5, -7, -5, -24], [-1, 4, 25, -11, 12, 4, -4, -4, 9, -7, 4], [-10, -3, 6, -1, 14, -9, 6, 10, -5, 1, -10], [-7, -15, -6, -10, -6, -1, -9, -6, 11, -9, 1], [-13, 1, 4, 0, 2, 15, -10, -7, 17, 12, 10], [11, 16, 14, -16, 21, 1, 3, -1, 11, 4, 1], [-11, -1, -8, 22, 7, 1, 0, -2, -6, 2, 11], [26, -11, -9, 8, -10, -11, 0, -6, -5, 13, 0], [-17, 27, 2, -6, -1, -3, 12, -5, -2, 2, 2], [-5, -23, -15, 10, -23, -3, 0, 0, -4, 4, -7], [9, 8, 1, 11, 0, -6, 7, 11, -6, -2, 4], [-20, 13, -2, 4, -1, 1, -3, 12, 1, -2, 1], [-3, -3, -7, -13, 14, 4, 0, 14, -3, 4, -12], [-16, -2, -12, -4, 8, 14, -2, 2, -2, 10, -12], [-1, 17, -8, 14, -3, 15, 0, 12, -12, -8, 1], [-18, 0, 8, -6, 2, -19, 16, -1, -4, 4, 6], [-10, 12, 0, -4, 6, -10, 12, 4, -6, 2, 12], [22, 8, -1, 1, 0, -1, -6, -11, 7, 6, 7], [2, -27, 2, 5, -2, -14, -5, 5, 1, -6, 2], [13, -7, 0, 6, -2, 6, -8, 2, 1, 0, -6], [-18, -32, -5, 6, -2, 9, -6, 14, -5, -14, -2], [6, 5, -7, -16, -7, -4, 2, -3, -11, -9, -3], [20, -13, 5, 0, -12, 6, -12, -6, 13, 5, -9], [-15, -5, -20, -21, -1, -13, 5, -11, 11, 9, 1], [-24, -5, 4, -2, 6, 0, 12, -5, 4, -3, 3], [12, 23, 0, -14, -6, 5, -1, 2, 3, -4, -1], [-8, -4, -8, -24, -11, 14, -14, -5, 10, 2, -10], [7, -3, 2, 24, 6, 4, -2, 10, -4, -2, 9], [-25, 8, 7, -6, 4, -18, 9, -6, 1, 2, 14], [13, -1, 2, 6, 2, 7, -10, -7, 3, 0, 2], [5, 14, -10, 3, -13, -4, -6, -2, -7, 7, 3], [-34, 1, -13, 2, 0, 1, -4, -1, -3, 3, 5], [-2, -15, -5, 22, -16, 16, -8, 1, -2, -1, -13], [-15, -16, 1, -1, -20, -8, -12, -12, 7, 5, 10], [2, 5, -1, -6, 11, 11, 2, 4, -1, -7, 11], [2, 18, 14, 6, -2, -10, 4, -4, -4, -4, 8], [12, -3, -10, 15, -12, 12, -3, 17, -11, 2, -12], [2, -2, -22, -38, 2, 16, 2, 2, -4, 8, -14], [-11, -12, 14, 12, -7, -19, -3, -5, 2, 0, -1], [-2, -16, 9, -5, 3, -1, -6, 10, 6, -12, 6], [22, 0, 5, 2, 10, 2, 3, 1, -1, -5, -6], [-5, -7, -1, -32, 13, 3, -5, -2, -2, 7, -3], [-27, -13, -1, 11, -3, -8, -2, -12, 11, -2, 27], [30, -13, 14, 1, 3, 17, -10, 6, 10, -3, -13], [16, 19, 3, 9, -8, -4, -1, 9, -3, -6, -9], [-38, 11, 5, -12, 6, -31, 2, -14, -3, 17, 0], [31, -9, -10, -3, -8, 8, -17, 1, 2, 7, -9], [15, -7, 8, -18, 2, 6, -2, 4, 1, 0, -6], [-14, -1, -1, 8, 5, 17, -4, 16, 1, -11, -7], [-5, 14, -7, -16, -5, -2, 6, -7, -12, 5, -3]]
